import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import (
    AccountAccountCounters,
    AccountInfo,
    AccountPushSettings,
    AccountUserSettings,
    BaseUserGroupFields,
)
from vkbottle_types.responses.account import *  # noqa: F401,F403  # type: ignore
from vkbottle_types.responses.base import (
    BaseOkResponse,
    BaseOkResponseModel,
)


class AccountCategory(BaseCategory):
    async def ban(
        self,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `account.ban()`

        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.ban", params)
        model = BaseOkResponse
        return model(**response).response

    async def change_password(
        self,
        new_password: str,
        change_password_hash: str | None = None,
        old_password: str | None = None,
        restore_sid: str | None = None,
        **kwargs: typing.Any,
    ) -> AccountChangePasswordResponseModel:
        """Method `account.changePassword()`

        :param new_password: New password that will be set as a current
        :param change_password_hash: Hash received after a successful OAuth authorization with a code got by SMS. (If the password is changed right after the access was restored)
        :param old_password: Current user password.
        :param restore_sid: Session id received after the [vk.com/dev/auth.restore|auth.restore] method is executed. (If the password is changed right after the access was restored)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.changePassword", params)
        model = AccountChangePasswordResponse
        return model(**response).response

    async def get_active_offers(
        self,
        count: int | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> AccountGetActiveOffersResponseModel:
        """Method `account.getActiveOffers()`

        :param count: Number of results to return.
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.getActiveOffers", params)
        model = AccountGetActiveOffersResponse
        return model(**response).response

    async def get_app_permissions(
        self,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `account.getAppPermissions()`

        :param user_id: User ID whose settings information shall be got. By default: current user.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.getAppPermissions", params)
        model = AccountGetAppPermissionsResponse
        return model(**response).response

    async def get_banned(
        self,
        count: int | None = None,
        fields: list[BaseUserGroupFields] | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> AccountGetBannedResponseModel:
        """Method `account.getBanned()`

        :param count: Number of results to return.
        :param fields: Additional fields of [vk.com/dev/fields|profiles] and [vk.com/dev/fields_groups|communities] to return.
        :param offset: Offset needed to return a specific subset of results.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.getBanned", params)
        model = AccountGetBannedResponse
        return model(**response).response

    async def get_counters(
        self,
        filter: list[str] | None = None,
        **kwargs: typing.Any,
    ) -> "AccountAccountCounters":
        """Method `account.getCounters()`

        :param filter: Counters to be returned.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.getCounters", params)
        model = AccountGetCountersResponse
        return model(**response).response

    async def get_info(
        self,
        fields: list[typing.Literal["country", "https_required", "own_posts_default", "no_wall_replies", "intro", "lang", "audio_autoplay"]]
        | None = None,
        **kwargs: typing.Any,
    ) -> "AccountInfo":
        """Method `account.getInfo()`

        :param fields: Fields to return. Possible values: *'country' - user country,, *'https_required' - is "HTTPS only" option enabled,, *'own_posts_default' - is "Show my posts only" option is enabled,, *'no_wall_replies' - are wall replies disabled or not,, *'intro' - is intro passed by user or not,, *'lang' - user language. By default: all.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.getInfo", params)
        model = AccountGetInfoResponse
        return model(**response).response

    async def get_profile_info(
        self,
        **kwargs: typing.Any,
    ) -> "AccountUserSettings":
        """Method `account.getProfileInfo()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("account.getProfileInfo", params)
        model = AccountGetProfileInfoResponse
        return model(**response).response

    async def get_push_settings(
        self,
        device_id: str | None = None,
        **kwargs: typing.Any,
    ) -> "AccountPushSettings":
        """Method `account.getPushSettings()`

        :param device_id: Unique device ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.getPushSettings", params)
        model = AccountGetPushSettingsResponse
        return model(**response).response

    async def register_device(
        self,
        device_id: str,
        token: str,
        device_model: str | None = None,
        device_year: int | None = None,
        pushes_granted: bool | None = None,
        sandbox: bool | None = None,
        settings: str | None = None,
        system_version: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `account.registerDevice()`

        :param device_id: Unique device ID.
        :param token: Device token used to send notifications. (for mpns, the token shall be URL for sending of notifications)
        :param device_model: String name of device model.
        :param device_year: Device year.
        :param pushes_granted:
        :param sandbox:
        :param settings: Push settings in a [vk.com/dev/push_settings|special format].
        :param system_version: String version of device operating system.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.registerDevice", params)
        model = BaseOkResponse
        return model(**response).response

    async def save_profile_info(
        self,
        bdate: str | None = None,
        bdate_visibility: int | None = None,
        cancel_request_id: int | None = None,
        city_id: int | None = None,
        country_id: int | None = None,
        first_name: str | None = None,
        home_town: str | None = None,
        last_name: str | None = None,
        maiden_name: str | None = None,
        relation: int | None = None,
        relation_partner_id: int | None = None,
        screen_name: str | None = None,
        sex: int | None = None,
        status: str | None = None,
        **kwargs: typing.Any,
    ) -> AccountSaveProfileInfoResponseModel:
        """Method `account.saveProfileInfo()`

        :param bdate: User birth date, format: DD.MM.YYYY.
        :param bdate_visibility: Birth date visibility. Returned values: , * '1' - show birth date,, * '2' - show only month and day,, * '0' - hide birth date.
        :param cancel_request_id: ID of the name change request to be canceled. If this parameter is sent, all the others are ignored.
        :param city_id: User city.
        :param country_id: User country.
        :param first_name: User first name.
        :param home_town: User home town.
        :param last_name: User last name.
        :param maiden_name: User maiden name (female only)
        :param relation: User relationship status. Possible values: , * '1' - single,, * '2' - in a relationship,, * '3' - engaged,, * '4' - married,, * '5' - it's complicated,, * '6' - actively searching,, * '7' - in love,, * '0' - not specified.
        :param relation_partner_id: ID of the relationship partner.
        :param screen_name: User screen name.
        :param sex: User sex. Possible values: , * '1' - female,, * '2' - male.
        :param status: Status text.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.saveProfileInfo", params)
        model = AccountSaveProfileInfoResponse
        return model(**response).response

    async def set_info(
        self,
        name: str | None = None,
        value: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `account.setInfo()`

        :param name: Setting name.
        :param value: Setting value.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.setInfo", params)
        model = BaseOkResponse
        return model(**response).response

    async def set_offline(
        self,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `account.setOffline()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("account.setOffline", params)
        model = BaseOkResponse
        return model(**response).response

    async def set_online(
        self,
        voip: bool | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `account.setOnline()`

        :param voip: '1' if videocalls are available for current device.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.setOnline", params)
        model = BaseOkResponse
        return model(**response).response

    async def set_push_settings(
        self,
        device_id: str,
        key: str | None = None,
        settings: str | None = None,
        value: list[str] | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `account.setPushSettings()`

        :param device_id: Unique device ID.
        :param key: Notification key.
        :param settings: Push settings in a [vk.com/dev/push_settings|special format].
        :param value: New value for the key in a [vk.com/dev/push_settings|special format].
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.setPushSettings", params)
        model = BaseOkResponse
        return model(**response).response

    async def set_silence_mode(
        self,
        device_id: str | None = None,
        peer_id: int | None = None,
        sound: int | None = None,
        time: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `account.setSilenceMode()`

        :param device_id: Unique device ID.
        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'Chat ID', e.g. '2000000001'. For community: '- Community ID', e.g. '-12345'. "
        :param sound: '1' - to enable sound in this dialog, '0' - to disable sound. Only if 'peer_id' contains user or community ID.
        :param time: Time in seconds for what notifications should be disabled. '-1' to disable forever.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.setSilenceMode", params)
        model = BaseOkResponse
        return model(**response).response

    async def unban(
        self,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `account.unban()`

        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.unban", params)
        model = BaseOkResponse
        return model(**response).response

    async def unregister_device(
        self,
        device_id: str | None = None,
        sandbox: bool | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `account.unregisterDevice()`

        :param device_id: Unique device ID.
        :param sandbox:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.unregisterDevice", params)
        model = BaseOkResponse
        return model(**response).response


__all__ = ("AccountCategory",)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import OrdersAmount, OrdersOrder, OrdersSubscription
from vkbottle_types.responses.base import (
    BaseBoolResponse,
)
from vkbottle_types.responses.orders import *  # noqa: F401,F403  # type: ignore


class OrdersCategory(BaseCategory):
    async def cancel_subscription(
        self,
        subscription_id: int,
        user_id: int,
        pending_cancel: bool | None = None,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `orders.cancelSubscription()`

        :param subscription_id:
        :param user_id:
        :param pending_cancel:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("orders.cancelSubscription", params)
        model = BaseBoolResponse
        return model(**response).response

    async def change_state(
        self,
        action: str,
        order_id: int,
        app_order_id: int | None = None,
        test_mode: bool | None = None,
        **kwargs: typing.Any,
    ) -> str:
        """Method `orders.changeState()`

        :param action: action to be done with the order. Available actions: *cancel - to cancel unconfirmed order. *charge - to confirm unconfirmed order. Applies only if processing of [vk.com/dev/payments_status|order_change_state] notification failed. *refund - to cancel confirmed order.
        :param order_id: order ID.
        :param app_order_id: internal ID of the order in the application.
        :param test_mode: if this parameter is set to 1, this method returns a list of test mode orders. By default - 0.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("orders.changeState", params)
        model = OrdersChangeStateResponse
        return model(**response).response

    async def get(
        self,
        count: int | None = None,
        offset: int | None = None,
        test_mode: bool | None = None,
        **kwargs: typing.Any,
    ) -> list[OrdersOrder]:
        """Method `orders.get()`

        :param count: number of returned orders.
        :param offset:
        :param test_mode: if this parameter is set to 1, this method returns a list of test mode orders. By default - 0.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("orders.get", params)
        model = OrdersGetResponse
        return model(**response).response

    async def get_amount(
        self,
        user_id: int,
        votes: list[str],
        **kwargs: typing.Any,
    ) -> list[OrdersAmount]:
        """Method `orders.getAmount()`

        :param user_id:
        :param votes:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("orders.getAmount", params)
        model = OrdersGetAmountResponse
        return model(**response).response

    async def get_by_id(
        self,
        order_id: int | None = None,
        order_ids: list[int] | None = None,
        test_mode: bool | None = None,
        **kwargs: typing.Any,
    ) -> list[OrdersOrder]:
        """Method `orders.getById()`

        :param order_id: order ID.
        :param order_ids: order IDs (when information about several orders is requested).
        :param test_mode: if this parameter is set to 1, this method returns a list of test mode orders. By default - 0.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("orders.getById", params)
        model = OrdersGetByIdResponse
        return model(**response).response

    async def get_user_subscription_by_id(
        self,
        subscription_id: int,
        user_id: int,
        **kwargs: typing.Any,
    ) -> "OrdersSubscription":
        """Method `orders.getUserSubscriptionById()`

        :param subscription_id:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("orders.getUserSubscriptionById", params)
        model = OrdersGetUserSubscriptionByIdResponse
        return model(**response).response

    async def get_user_subscriptions(
        self,
        user_id: int,
        **kwargs: typing.Any,
    ) -> OrdersGetUserSubscriptionsResponseModel:
        """Method `orders.getUserSubscriptions()`

        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("orders.getUserSubscriptions", params)
        model = OrdersGetUserSubscriptionsResponse
        return model(**response).response


__all__ = ("OrdersCategory",)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import BaseUserGroupFields, StoriesStoryStats
from vkbottle_types.responses.base import (
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.stories import *  # noqa: F401,F403  # type: ignore


class StoriesCategory(BaseCategory):
    async def ban_owner(
        self,
        owners_ids: list[int],
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `stories.banOwner()`

        :param owners_ids: List of sources IDs
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.banOwner", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete(
        self,
        owner_id: int | None = None,
        stories: list[str] | None = None,
        story_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `stories.delete()`

        :param owner_id: Story owner's ID. Current user id is used by default.
        :param stories:
        :param story_id: Story ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.delete", params)
        model = BaseOkResponse
        return model(**response).response

    async def get(
        self,
        extended: bool | None = None,
        fields: list[BaseUserGroupFields] | None = None,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> StoriesGetV5113ResponseModel:
        """Method `stories.get()`

        :param extended: '1' - to return additional fields for users and communities. Default value is 0.
        :param fields:
        :param owner_id: Owner ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.get", params)
        model = StoriesGetV5113Response
        return model(**response).response

    @typing.overload
    async def get_banned(
        self,
        extended: typing.Literal[True],
        fields: list[BaseUserGroupFields] | None = None,
        **kwargs: typing.Any,
    ) -> StoriesGetBannedExtendedResponseModel: ...

    @typing.overload
    async def get_banned(
        self,
        extended: typing.Literal[False] | None = None,
        fields: list[BaseUserGroupFields] | None = None,
        **kwargs: typing.Any,
    ) -> StoriesGetBannedResponseModel: ...

    async def get_banned(
        self,
        extended: bool | None = None,
        fields: list[BaseUserGroupFields] | None = None,
        **kwargs: typing.Any,
    ) -> StoriesGetBannedExtendedResponseModel | StoriesGetBannedResponseModel:
        """Method `stories.getBanned()`

        :param extended: '1' - to return additional fields for users and communities. Default value is 0.
        :param fields: Additional fields to return
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.getBanned", params)
        model = self.get_model(
            ((("extended",), StoriesGetBannedExtendedResponse),),
            default=StoriesGetBannedResponse,
            params=params,
        )
        return model(**response).response

    async def get_by_id(
        self,
        stories: list[str],
        extended: bool | None = None,
        fields: list[BaseUserGroupFields] | None = None,
        **kwargs: typing.Any,
    ) -> StoriesGetByIdExtendedResponseModel:
        """Method `stories.getById()`

        :param stories: Stories IDs separated by commas. Use format {owner_id}+'_'+{story_id}, for example, 12345_54331.
        :param extended: '1' - to return additional fields for users and communities. Default value is 0.
        :param fields: Additional fields to return
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.getById", params)
        model = StoriesGetByIdExtendedResponse
        return model(**response).response

    async def get_photo_upload_server(
        self,
        add_to_news: bool | None = None,
        clickable_stickers: str | None = None,
        group_id: int | None = None,
        link_text: str | None = None,
        link_url: str | None = None,
        reply_to_story: str | None = None,
        user_ids: list[int] | None = None,
        **kwargs: typing.Any,
    ) -> StoriesGetPhotoUploadServerResponseModel:
        """Method `stories.getPhotoUploadServer()`

        :param add_to_news: 1 - to add the story to friend's feed.
        :param clickable_stickers:
        :param group_id: ID of the community to upload the story (should be verified or with the "fire" icon).
        :param link_text: Link text (for community's stories only).
        :param link_url: Link URL. Internal links on https://vk.com only.
        :param reply_to_story: ID of the story to reply with the current.
        :param user_ids: List of users IDs who can see the story.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.getPhotoUploadServer", params)
        model = StoriesGetPhotoUploadServerResponse
        return model(**response).response

    async def get_replies(
        self,
        owner_id: int,
        story_id: int,
        access_key: str | None = None,
        extended: bool | None = None,
        fields: list[BaseUserGroupFields] | None = None,
        **kwargs: typing.Any,
    ) -> StoriesGetV5113ResponseModel:
        """Method `stories.getReplies()`

        :param owner_id: Story owner ID.
        :param story_id: Story ID.
        :param access_key: Access key for the private object.
        :param extended: '1' - to return additional fields for users and communities. Default value is 0.
        :param fields: Additional fields to return
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.getReplies", params)
        model = StoriesGetV5113Response
        return model(**response).response

    async def get_stats(
        self,
        owner_id: int,
        story_id: int,
        **kwargs: typing.Any,
    ) -> "StoriesStoryStats":
        """Method `stories.getStats()`

        :param owner_id: Story owner ID.
        :param story_id: Story ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.getStats", params)
        model = StoriesGetStatsResponse
        return model(**response).response

    async def get_video_upload_server(
        self,
        add_to_news: bool | None = None,
        clickable_stickers: str | None = None,
        group_id: int | None = None,
        link_text: str | None = None,
        link_url: str | None = None,
        reply_to_story: str | None = None,
        user_ids: list[int] | None = None,
        **kwargs: typing.Any,
    ) -> StoriesGetVideoUploadServerResponseModel:
        """Method `stories.getVideoUploadServer()`

        :param add_to_news: 1 - to add the story to friend's feed.
        :param clickable_stickers:
        :param group_id: ID of the community to upload the story (should be verified or with the "fire" icon).
        :param link_text: Link text (for community's stories only).
        :param link_url: Link URL. Internal links on https://vk.com only.
        :param reply_to_story: ID of the story to reply with the current.
        :param user_ids: List of users IDs who can see the story.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.getVideoUploadServer", params)
        model = StoriesGetVideoUploadServerResponse
        return model(**response).response

    async def get_viewers(
        self,
        story_id: int,
        count: int | None = None,
        extended: bool | None = None,
        fields: list[BaseUserGroupFields] | None = None,
        offset: int | None = None,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> StoriesGetViewersExtendedV5115ResponseModel:
        """Method `stories.getViewers()`

        :param story_id: Story ID.
        :param count: Maximum number of results.
        :param extended: '1' - to return detailed information about photos
        :param fields:
        :param offset: Offset needed to return a specific subset of results.
        :param owner_id: Story owner ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.getViewers", params)
        model = StoriesGetViewersExtendedV5115Response
        return model(**response).response

    async def hide_all_replies(
        self,
        owner_id: int,
        group_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `stories.hideAllReplies()`

        :param owner_id: ID of the user whose replies should be hidden.
        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.hideAllReplies", params)
        model = BaseOkResponse
        return model(**response).response

    async def hide_reply(
        self,
        owner_id: int,
        story_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `stories.hideReply()`

        :param owner_id: ID of the user whose replies should be hidden.
        :param story_id: Story ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.hideReply", params)
        model = BaseOkResponse
        return model(**response).response

    async def save(
        self,
        extended: bool | None = None,
        fields: list[BaseUserGroupFields] | None = None,
        upload_results: list[str] | None = None,
        upload_results_json: str | None = None,
        **kwargs: typing.Any,
    ) -> StoriesSaveResponseModel:
        """Method `stories.save()`

        :param extended:
        :param fields:
        :param upload_results:
        :param upload_results_json:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.save", params)
        model = StoriesSaveResponse
        return model(**response).response

    async def search(
        self,
        count: int | None = None,
        extended: bool | None = None,
        fields: list[BaseUserGroupFields] | None = None,
        latitude: float | None = None,
        longitude: float | None = None,
        mentioned_id: int | None = None,
        place_id: int | None = None,
        q: str | None = None,
        radius: int | None = None,
        **kwargs: typing.Any,
    ) -> StoriesGetV5113ResponseModel:
        """Method `stories.search()`

        :param count:
        :param extended:
        :param fields:
        :param latitude:
        :param longitude:
        :param mentioned_id:
        :param place_id:
        :param q:
        :param radius:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.search", params)
        model = StoriesGetV5113Response
        return model(**response).response

    async def send_interaction(
        self,
        access_key: str,
        is_anonymous: bool | None = None,
        is_broadcast: bool | None = None,
        message: str | None = None,
        unseen_marker: bool | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `stories.sendInteraction()`

        :param access_key:
        :param is_anonymous:
        :param is_broadcast:
        :param message:
        :param unseen_marker:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.sendInteraction", params)
        model = BaseOkResponse
        return model(**response).response

    async def unban_owner(
        self,
        owners_ids: list[int],
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `stories.unbanOwner()`

        :param owners_ids: List of hidden sources to show stories from.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stories.unbanOwner", params)
        model = BaseOkResponse
        return model(**response).response


__all__ = ("StoriesCategory",)



from vkbottle_types import *  # noqa
from vkbottle_types.methods import *  # noqa
from vkbottle_types.objects import *  # noqa
from vkbottle_types.responses import *  # noqa


def test_imports():
    # this library is to complicated to test
    # so we just test that it can be imported
    pass


if __name__ == "__main__":
    test_imports()



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import PagesWikipage, PagesWikipageFull, PagesWikipageHistory
from vkbottle_types.responses.base_response import BaseResponse


class PagesGetHistoryResponse(BaseResponse):
    response: list["PagesWikipageHistory"] = Field()


class PagesGetTitlesResponse(BaseResponse):
    response: list["PagesWikipage"] = Field()


class PagesGetVersionResponseModel(BaseModel):
    id: int = Field()
    page_id: int = Field()
    group_id: int = Field()
    title: str = Field()
    source: str = Field()
    current_user_can_edit: int = Field()
    who_can_view: int = Field()
    who_can_edit: int = Field()
    version_created: int = Field()
    creator_id: int | None = Field(
        default=None,
    )
    parent: str | None = Field(
        default=None,
    )
    parent2: str | None = Field(
        default=None,
    )
    html: str | None = Field(
        default=None,
    )


class PagesGetVersionResponse(BaseResponse):
    response: "PagesGetVersionResponseModel" = Field()


class PagesGetResponse(BaseResponse):
    response: "PagesWikipageFull" = Field()


class PagesParseWikiResponse(BaseResponse):
    response: str = Field()


class PagesSaveAccessResponse(BaseResponse):
    response: int = Field()


class PagesSaveResponse(BaseResponse):
    response: int = Field()



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import CallsShortCredentials
from vkbottle_types.responses.base_response import BaseResponse


class CallsStartResponseModel(BaseModel):
    join_link: str = Field()
    ok_join_link: str = Field()
    call_id: str | None = Field(
        default=None,
    )
    broadcast_video_id: str | None = Field(
        default=None,
    )
    broadcast_ov_id: str | None = Field(
        default=None,
    )
    short_credentials: "CallsShortCredentials | None" = Field(
        default=None,
    )


class CallsStartResponse(BaseResponse):
    response: "CallsStartResponseModel" = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import (
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.board import *  # noqa: F401,F403  # type: ignore


class BoardCategory(BaseCategory):
    async def add_topic(
        self,
        group_id: int,
        title: str,
        attachments: list[str] | None = None,
        from_group: bool | None = None,
        text: str | None = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `board.addTopic()`

        :param group_id: ID of the community that owns the discussion board.
        :param title: Topic title.
        :param attachments: List of media objects attached to the topic, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' - Type of media object: 'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document, '<owner_id>' - ID of the media owner. '<media_id>' - Media ID. Example: "photo100172_166443618,photo66748_265827614", , "NOTE: If you try to attach more than one reference, an error will be thrown.",
        :param from_group: For a community: '1' - to post the topic as by the community, '0' - to post the topic as by the user (default)
        :param text: Text of the topic.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.addTopic", params)
        model = BoardAddTopicResponse
        return model(**response).response

    async def close_topic(
        self,
        group_id: int,
        topic_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `board.closeTopic()`

        :param group_id: ID of the community that owns the discussion board.
        :param topic_id: Topic ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.closeTopic", params)
        model = BaseOkResponse
        return model(**response).response

    async def create_comment(
        self,
        group_id: int,
        topic_id: int,
        attachments: list[str] | None = None,
        from_group: bool | None = None,
        guid: str | None = None,
        message: str | None = None,
        sticker_id: int | None = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `board.createComment()`

        :param group_id: ID of the community that owns the discussion board.
        :param topic_id: ID of the topic to be commented on.
        :param attachments: (Required if 'text' is not set.) List of media objects attached to the comment, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' - Type of media object: 'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document, '<owner_id>' - ID of the media owner. '<media_id>' - Media ID.
        :param from_group: '1' - to post the comment as by the community, '0' - to post the comment as by the user (default)
        :param guid: Unique identifier to avoid repeated comments.
        :param message: (Required if 'attachments' is not set.) Text of the comment.
        :param sticker_id: Sticker ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.createComment", params)
        model = BoardCreateCommentResponse
        return model(**response).response

    async def delete_comment(
        self,
        comment_id: int,
        group_id: int,
        topic_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `board.deleteComment()`

        :param comment_id: Comment ID.
        :param group_id: ID of the community that owns the discussion board.
        :param topic_id: Topic ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.deleteComment", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete_topic(
        self,
        group_id: int,
        topic_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `board.deleteTopic()`

        :param group_id: ID of the community that owns the discussion board.
        :param topic_id: Topic ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.deleteTopic", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_comment(
        self,
        comment_id: int,
        group_id: int,
        topic_id: int,
        attachments: list[str] | None = None,
        message: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `board.editComment()`

        :param comment_id: ID of the comment on the topic.
        :param group_id: ID of the community that owns the discussion board.
        :param topic_id: Topic ID.
        :param attachments: (Required if 'message' is not set.) List of media objects attached to the comment, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' - Type of media object: 'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document, '<owner_id>' - ID of the media owner. '<media_id>' - Media ID. Example: "photo100172_166443618,photo66748_265827614"
        :param message: (Required if 'attachments' is not set). New comment text.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.editComment", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_topic(
        self,
        group_id: int,
        title: str,
        topic_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `board.editTopic()`

        :param group_id: ID of the community that owns the discussion board.
        :param title: New title of the topic.
        :param topic_id: Topic ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.editTopic", params)
        model = BaseOkResponse
        return model(**response).response

    async def fix_topic(
        self,
        group_id: int,
        topic_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `board.fixTopic()`

        :param group_id: ID of the community that owns the discussion board.
        :param topic_id: Topic ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.fixTopic", params)
        model = BaseOkResponse
        return model(**response).response

    @typing.overload
    async def get_comments(
        self,
        group_id: int,
        topic_id: int,
        extended: typing.Literal[True],
        count: int | None = None,
        need_likes: bool | None = None,
        offset: int | None = None,
        sort: str | None = None,
        start_comment_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BoardGetCommentsExtendedResponseModel: ...

    @typing.overload
    async def get_comments(
        self,
        group_id: int,
        topic_id: int,
        extended: typing.Literal[False] | None = None,
        count: int | None = None,
        need_likes: bool | None = None,
        offset: int | None = None,
        sort: str | None = None,
        start_comment_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BoardGetCommentsResponseModel: ...

    async def get_comments(
        self,
        group_id: int,
        topic_id: int,
        extended: bool | None = None,
        count: int | None = None,
        need_likes: bool | None = None,
        offset: int | None = None,
        sort: str | None = None,
        start_comment_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BoardGetCommentsResponseModel | BoardGetCommentsExtendedResponseModel:
        """Method `board.getComments()`

        :param group_id: ID of the community that owns the discussion board.
        :param topic_id: Topic ID.
        :param extended: '1' - to return information about users who posted comments, '0' - to return no additional fields (default)
        :param count: Number of comments to return.
        :param need_likes: '1' - to return the 'likes' field, '0' - not to return the 'likes' field (default)
        :param offset: Offset needed to return a specific subset of comments.
        :param sort: Sort order: 'asc' - by creation date in chronological order, 'desc' - by creation date in reverse chronological order,
        :param start_comment_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.getComments", params)
        model = self.get_model(
            ((("extended",), BoardGetCommentsExtendedResponse),),
            default=BoardGetCommentsResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload
    async def get_topics(
        self,
        group_id: int,
        extended: typing.Literal[True],
        count: int | None = None,
        offset: int | None = None,
        order: int | None = None,
        preview: int | None = None,
        preview_length: int | None = None,
        topic_ids: list[int] | None = None,
        **kwargs: typing.Any,
    ) -> BoardGetTopicsExtendedResponseModel: ...

    @typing.overload
    async def get_topics(
        self,
        group_id: int,
        extended: typing.Literal[False] | None = None,
        count: int | None = None,
        offset: int | None = None,
        order: int | None = None,
        preview: int | None = None,
        preview_length: int | None = None,
        topic_ids: list[int] | None = None,
        **kwargs: typing.Any,
    ) -> BoardGetTopicsResponseModel: ...

    async def get_topics(
        self,
        group_id: int,
        extended: bool | None = None,
        count: int | None = None,
        offset: int | None = None,
        order: int | None = None,
        preview: int | None = None,
        preview_length: int | None = None,
        topic_ids: list[int] | None = None,
        **kwargs: typing.Any,
    ) -> BoardGetTopicsResponseModel | BoardGetTopicsExtendedResponseModel:
        """Method `board.getTopics()`

        :param group_id: ID of the community that owns the discussion board.
        :param extended: '1' - to return information about users who created topics or who posted there last, '0' - to return no additional fields (default)
        :param count: Number of topics to return.
        :param offset: Offset needed to return a specific subset of topics.
        :param order: Sort order: '1' - by date updated in reverse chronological order. '2' - by date created in reverse chronological order. '-1' - by date updated in chronological order. '-2' - by date created in chronological order. If no sort order is specified, topics are returned in the order specified by the group administrator. Pinned topics are returned first, regardless of the sorting.
        :param preview: '1' - to return the first comment in each topic,, '2' - to return the last comment in each topic,, '0' - to return no comments. By default: '0'.
        :param preview_length: Number of characters after which to truncate the previewed comment. To preview the full comment, specify '0'.
        :param topic_ids: IDs of topics to be returned (100 maximum). By default, all topics are returned. If this parameter is set, the 'order', 'offset', and 'count' parameters are ignored.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.getTopics", params)
        model = self.get_model(
            ((("extended",), BoardGetTopicsExtendedResponse),),
            default=BoardGetTopicsResponse,
            params=params,
        )
        return model(**response).response

    async def open_topic(
        self,
        group_id: int,
        topic_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `board.openTopic()`

        :param group_id: ID of the community that owns the discussion board.
        :param topic_id: Topic ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.openTopic", params)
        model = BaseOkResponse
        return model(**response).response

    async def restore_comment(
        self,
        comment_id: int,
        group_id: int,
        topic_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `board.restoreComment()`

        :param comment_id: Comment ID.
        :param group_id: ID of the community that owns the discussion board.
        :param topic_id: Topic ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.restoreComment", params)
        model = BaseOkResponse
        return model(**response).response

    async def unfix_topic(
        self,
        group_id: int,
        topic_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `board.unfixTopic()`

        :param group_id: ID of the community that owns the discussion board.
        :param topic_id: Topic ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("board.unfixTopic", params)
        model = BaseOkResponse
        return model(**response).response


__all__ = ("BoardCategory",)



from typing import TypeAlias

from .user_events import (
    AddConversationsToFolder,
    Call,
    ChangeFolderOrder,
    ChatEdit,
    ChatInfoEdit,
    ChatTypingState,
    ChatVoiceMessageStates,
    Counter,
    CounterUnreadDialogsInFolders,
    CreateFolder,
    DeleteFolder,
    DialogFlagsReplace,
    DialogResetFlags,
    DialogSetFlags,
    DialogTypingState,
    FriendAction,
    FriendOffline,
    FriendOnline,
    InRead,
    MessageEdit,
    MessageFlagsReplace,
    MessageNew,
    MessageResetFlags,
    MessagesDelete,
    MessageSetFlags,
    MessagesRestore,
    NotificationsSettingsChanged,
    OutRead,
    RawUserEvent,
    RemoveConversationsFromFolder,
    RenameFolder,
    UsersTypingState,
)


class UserTypes:
    RawUserEvent: TypeAlias = RawUserEvent
    MessageFlagsReplace: TypeAlias = MessageFlagsReplace
    MessageSetFlags: TypeAlias = MessageSetFlags
    MessageResetFlags: TypeAlias = MessageResetFlags
    MessageNew: TypeAlias = MessageNew
    MessageEdit: TypeAlias = MessageEdit
    MessagesDelete: TypeAlias = MessagesDelete
    MessagesRestore: TypeAlias = MessagesRestore
    ChatVoiceMessageStates: TypeAlias = ChatVoiceMessageStates
    ChatEdit: TypeAlias = ChatEdit
    ChatInfoEdit: TypeAlias = ChatInfoEdit
    ChatTypingState: TypeAlias = ChatTypingState
    DialogTypingState: TypeAlias = DialogTypingState
    UsersTypingState: TypeAlias = UsersTypingState
    DialogResetFlags: TypeAlias = DialogResetFlags
    DialogFlagsReplace: TypeAlias = DialogFlagsReplace
    DialogSetFlags: TypeAlias = DialogSetFlags
    FriendOnline: TypeAlias = FriendOnline
    FriendOffline: TypeAlias = FriendOffline
    Counter: TypeAlias = Counter
    Call: TypeAlias = Call
    FriendAction: TypeAlias = FriendAction
    NotificationsSettingsChanged: TypeAlias = NotificationsSettingsChanged
    InRead: TypeAlias = InRead
    OutRead: TypeAlias = OutRead
    CreateFolder: TypeAlias = CreateFolder
    RenameFolder: TypeAlias = RenameFolder
    DeleteFolder: TypeAlias = DeleteFolder
    AddConversationsToFolder: TypeAlias = AddConversationsToFolder
    RemoveConversationsFromFolder: TypeAlias = RemoveConversationsFromFolder
    ChangeFolderOrder: TypeAlias = ChangeFolderOrder
    CounterUnreadDialogsInFolders: TypeAlias = CounterUnreadDialogsInFolders


__all__ = ("UserTypes",)



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    GroupsGroupFull,
    UsersUser,
    UsersUserFull,
    VideoLiveCategory,
    VideoSaveResult,
    VideoStreamInputParams,
    VideoVideoAlbum,
    VideoVideoAlbumFull,
    VideoVideoFull,
    VideoVideoImage,
    WallWallComment,
)
from vkbottle_types.responses.base_response import BaseResponse


class VideoAddAlbumResponseModel(BaseModel):
    album_id: int = Field()


class VideoAddAlbumResponse(BaseResponse):
    response: "VideoAddAlbumResponseModel" = Field()


class VideoChangeVideoAlbumsResponse(BaseResponse):
    response: list[int] = Field()


class VideoCreateCommentResponse(BaseResponse):
    response: int = Field()


class VideoEditResponseModel(BaseModel):
    success: bool = Field()
    access_key: str | None = Field(
        default=None,
    )


class VideoEditResponse(BaseResponse):
    response: "VideoEditResponseModel" = Field()


class VideoGetAlbumByIdResponse(BaseResponse):
    response: "VideoVideoAlbumFull" = Field()


class VideoGetAlbumsByVideoExtendedResponseModel(BaseModel):
    count: int = Field()
    items: list["VideoVideoAlbumFull"] = Field()


class VideoGetAlbumsByVideoExtendedResponse(BaseResponse):
    response: "VideoGetAlbumsByVideoExtendedResponseModel" = Field()


class VideoGetAlbumsByVideoResponse(BaseResponse):
    response: list[int] = Field()


class VideoGetAlbumsExtendedResponseModel(BaseModel):
    count: int = Field()
    items: list["VideoVideoAlbumFull"] = Field()


class VideoGetAlbumsExtendedResponse(BaseResponse):
    response: "VideoGetAlbumsExtendedResponseModel" = Field()


class VideoGetAlbumsResponseModel(BaseModel):
    count: int = Field()
    items: list["VideoVideoAlbum"] = Field()


class VideoGetAlbumsResponse(BaseResponse):
    response: "VideoGetAlbumsResponseModel" = Field()


class VideoGetCommentsExtendedResponseModel(BaseModel):
    count: int = Field()
    items: list["WallWallComment"] = Field()
    profiles: list["UsersUserFull"] = Field()
    groups: list["GroupsGroupFull"] = Field()
    current_level_count: int | None = Field(
        default=None,
    )
    can_post: bool | None = Field(
        default=None,
    )
    show_reply_button: bool | None = Field(
        default=None,
    )
    groups_can_post: bool | None = Field(
        default=None,
    )
    real_offset: int | None = Field(
        default=None,
    )


class VideoGetCommentsExtendedResponse(BaseResponse):
    response: "VideoGetCommentsExtendedResponseModel" = Field()


class VideoGetCommentsResponseModel(BaseModel):
    count: int = Field()
    items: list["WallWallComment"] = Field()
    current_level_count: int | None = Field(
        default=None,
    )
    can_post: bool | None = Field(
        default=None,
    )
    show_reply_button: bool | None = Field(
        default=None,
    )
    groups_can_post: bool | None = Field(
        default=None,
    )
    real_offset: int | None = Field(
        default=None,
    )


class VideoGetCommentsResponse(BaseResponse):
    response: "VideoGetCommentsResponseModel" = Field()


class VideoGetLongPollServerResponseModel(BaseModel):
    url: str = Field()


class VideoGetLongPollServerResponse(BaseResponse):
    response: "VideoGetLongPollServerResponseModel" = Field()


class VideoGetOembedResponseModel(BaseModel):
    version: str = Field()
    type: str = Field()
    html: str = Field()
    title: str | None = Field(
        default=None,
    )
    author_name: str | None = Field(
        default=None,
    )
    width: int | None = Field(
        default=None,
    )
    height: int | None = Field(
        default=None,
    )
    provider_name: str | None = Field(
        default=None,
    )
    provider_url: str | None = Field(
        default=None,
    )
    thumbnail_url: str | None = Field(
        default=None,
    )
    thumbnail_width: int | None = Field(
        default=None,
    )
    thumbnail_height: int | None = Field(
        default=None,
    )


class VideoGetOembedResponse(BaseResponse):
    response: "VideoGetOembedResponseModel" = Field()


class VideoGetThumbUploadUrlResponseModel(BaseModel):
    upload_url: str = Field()


class VideoGetThumbUploadUrlResponse(BaseResponse):
    response: "VideoGetThumbUploadUrlResponseModel" = Field()


class VideoGetResponseModel(BaseModel):
    count: int = Field()
    items: list["VideoVideoFull"] = Field()
    profiles: list["UsersUserFull"] | None = Field(
        default=None,
    )
    groups: list["GroupsGroupFull"] | None = Field(
        default=None,
    )
    max_attached_short_videos: int | None = Field(
        default=None,
    )


class VideoGetResponse(BaseResponse):
    response: "VideoGetResponseModel" = Field()


class VideoLiveGetCategoriesResponse(BaseResponse):
    response: list["VideoLiveCategory"] = Field()


class VideoSaveUploadedThumbResponseModel(BaseModel):
    photo_id: int = Field()
    photo_hash: str = Field()
    image: list["VideoVideoImage"] | None = Field(
        default=None,
    )
    photo_owner_id: int | None = Field(
        default=None,
    )


class VideoSaveUploadedThumbResponse(BaseResponse):
    response: "VideoSaveUploadedThumbResponseModel" = Field()


class VideoSaveResponse(BaseResponse):
    response: "VideoSaveResult" = Field()


class VideoSearchExtendedResponseModel(BaseModel):
    count: int = Field()
    items: list["VideoVideoFull"] = Field()
    profiles: list["UsersUser"] = Field()
    groups: list["GroupsGroupFull"] = Field()


class VideoSearchExtendedResponse(BaseResponse):
    response: "VideoSearchExtendedResponseModel" = Field()


class VideoSearchResponseModel(BaseModel):
    count: int = Field()
    items: list["VideoVideoFull"] = Field()


class VideoSearchResponse(BaseResponse):
    response: "VideoSearchResponseModel" = Field()


class VideoStartStreamingResponseModel(BaseModel):
    owner_id: int = Field()
    video_id: int = Field()
    name: str = Field()
    description: str = Field()
    access_key: str = Field()
    stream: "VideoStreamInputParams" = Field()
    post_id: int | None = Field(
        default=None,
    )


class VideoStartStreamingResponse(BaseResponse):
    response: "VideoStartStreamingResponseModel" = Field()


class VideoStopStreamingResponseModel(BaseModel):
    unique_viewers: int | None = Field(
        default=None,
    )


class VideoStopStreamingResponse(BaseResponse):
    response: "VideoStopStreamingResponseModel" = Field()


class VideoUploadResponseModel(BaseModel):
    size: int | None = Field(
        default=None,
    )
    video_id: int | None = Field(
        default=None,
    )


class VideoUploadResponse(BaseResponse):
    response: "VideoUploadResponseModel" = Field()



from typing import List

from vkbottle_types.codegen.responses.groups import *  # noqa: F403,F401
from vkbottle_types.objects import GroupsMemberRole, GroupsUserXtrRole
from vkbottle_types.responses.base_response import BaseResponse


class GetMembersFilterManagersResponse(BaseResponse):
    response: "GetMembersFilterManagersResponseModel"


class GetMembersFieldsFilterManagersResponse(BaseResponse):
    response: "GetMembersFieldsFilterManagersResponseModel"


class GetMembersFilterManagersResponseModel(BaseResponse):
    count: int | None = None
    items: List["GroupsMemberRole"] | None = None


class GetMembersFieldsFilterManagersResponseModel(BaseResponse):
    count: int | None = None
    items: List["GroupsUserXtrRole"] | None = None



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import PrettyCardsPrettyCard, PrettyCardsPrettyCardOrError
from vkbottle_types.responses.base_response import BaseResponse


class PrettyCardsCreateResponseModel(BaseModel):
    owner_id: int = Field()
    card_id: str = Field()


class PrettyCardsCreateResponse(BaseResponse):
    response: "PrettyCardsCreateResponseModel" = Field()


class PrettyCardsDeleteResponseModel(BaseModel):
    owner_id: int = Field()
    card_id: str = Field()
    error: str | None = Field(
        default=None,
    )


class PrettyCardsDeleteResponse(BaseResponse):
    response: "PrettyCardsDeleteResponseModel" = Field()


class PrettyCardsEditResponseModel(BaseModel):
    owner_id: int = Field()
    card_id: str = Field()


class PrettyCardsEditResponse(BaseResponse):
    response: "PrettyCardsEditResponseModel" = Field()


class PrettyCardsGetByIdResponse(BaseResponse):
    response: list["PrettyCardsPrettyCardOrError"] = Field()


class PrettyCardsGetUploadURLResponse(BaseResponse):
    response: str = Field()


class PrettyCardsGetResponseModel(BaseModel):
    count: int = Field()
    items: list["PrettyCardsPrettyCard"] = Field()


class PrettyCardsGetResponse(BaseResponse):
    response: "PrettyCardsGetResponseModel" = Field()



from .lib import apply_patches, generate_schema, get_schema_cli

if __name__ == "__main__":
    schema = get_schema_cli()
    apply_patches(schema)
    generate_schema(schema, "vkbottle_types/codegen")
    print()
    print("All done! ^_^")



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import UtilsDomainResolved, UtilsLinkChecked, UtilsLinkStats, UtilsLinkStatsExtended, UtilsShortLink
from vkbottle_types.responses.base import (
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.utils import *  # noqa: F401,F403  # type: ignore


class UtilsCategory(BaseCategory):
    async def check_link(
        self,
        url: str,
        **kwargs: typing.Any,
    ) -> "UtilsLinkChecked":
        """Method `utils.checkLink()`

        :param url: Link to check (e.g., 'http://google.com').
        """

        params = self.get_set_params(locals())
        response = await self.api.request("utils.checkLink", params)
        model = UtilsCheckLinkResponse
        return model(**response).response

    async def delete_from_last_shortened(
        self,
        key: str,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `utils.deleteFromLastShortened()`

        :param key: Link key (characters after vk.cc/).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("utils.deleteFromLastShortened", params)
        model = BaseOkResponse
        return model(**response).response

    async def get_last_shortened_links(
        self,
        count: int | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> UtilsGetLastShortenedLinksResponseModel:
        """Method `utils.getLastShortenedLinks()`

        :param count: Number of links to return.
        :param offset: Offset needed to return a specific subset of links.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("utils.getLastShortenedLinks", params)
        model = UtilsGetLastShortenedLinksResponse
        return model(**response).response

    @typing.overload
    async def get_link_stats(
        self,
        key: str,
        extended: typing.Literal[True],
        access_key: str | None = None,
        interval: str | None = None,
        intervals_count: int | None = None,
        source: str | None = None,
        **kwargs: typing.Any,
    ) -> "UtilsLinkStatsExtended": ...

    @typing.overload
    async def get_link_stats(
        self,
        key: str,
        extended: typing.Literal[False] | None = None,
        access_key: str | None = None,
        interval: str | None = None,
        intervals_count: int | None = None,
        source: str | None = None,
        **kwargs: typing.Any,
    ) -> "UtilsLinkStats": ...

    async def get_link_stats(
        self,
        key: str,
        extended: bool | None = None,
        access_key: str | None = None,
        interval: str | None = None,
        intervals_count: int | None = None,
        source: str | None = None,
        **kwargs: typing.Any,
    ) -> "UtilsLinkStats | UtilsLinkStatsExtended":
        """Method `utils.getLinkStats()`

        :param key: Link key (characters after vk.cc/).
        :param extended: 1 - to return extended stats data (sex, age, geo). 0 - to return views number only.
        :param access_key: Access key for private link stats.
        :param interval: Interval.
        :param intervals_count: Number of intervals to return.
        :param source: Source of scope
        """

        params = self.get_set_params(locals())
        response = await self.api.request("utils.getLinkStats", params)
        model = self.get_model(
            ((("extended",), UtilsGetLinkStatsExtendedResponse),),
            default=UtilsGetLinkStatsResponse,
            params=params,
        )
        return model(**response).response

    async def get_server_time(
        self,
        **kwargs: typing.Any,
    ) -> int:
        """Method `utils.getServerTime()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("utils.getServerTime", params)
        model = UtilsGetServerTimeResponse
        return model(**response).response

    async def get_short_link(
        self,
        url: str,
        private: bool | None = None,
        **kwargs: typing.Any,
    ) -> "UtilsShortLink":
        """Method `utils.getShortLink()`

        :param url: URL to be shortened.
        :param private: 1 - private stats, 0 - public stats.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("utils.getShortLink", params)
        model = UtilsGetShortLinkResponse
        return model(**response).response

    async def resolve_screen_name(
        self,
        screen_name: str,
        **kwargs: typing.Any,
    ) -> "UtilsDomainResolved":
        """Method `utils.resolveScreenName()`

        :param screen_name: Screen name of the user, community (e.g., 'apiclub,' 'andrew', or 'rules_of_war'), or application.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("utils.resolveScreenName", params)
        model = UtilsResolveScreenNameResponse
        return model(**response).response


__all__ = ("UtilsCategory",)



from typing import TypeAlias

from .bot_typings import GroupTypes
from .enums import GroupEventType, UserEventType
from .user_typings import UserTypes

Event: TypeAlias = UserEventType | GroupEventType


__all__ = ("Event", "GroupEventType", "GroupTypes", "UserEventType", "UserTypes")



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import BaseUploadServer, DocsDoc, DocsDocAttachmentType, DocsDocTypes, MessagesAudioMessage, MessagesGraffiti
from vkbottle_types.responses.base_response import BaseResponse


class DocsAddResponse(BaseResponse):
    response: int = Field()


class DocsDocUploadResponseModel(BaseModel):
    file: str | None = Field(
        default=None,
    )


class DocsDocUploadResponse(BaseResponse):
    response: "DocsDocUploadResponseModel" = Field()


class DocsGetByIdResponse(BaseResponse):
    response: list["DocsDoc"] = Field()


class DocsGetTypesResponseModel(BaseModel):
    count: int = Field()
    items: list["DocsDocTypes"] = Field()


class DocsGetTypesResponse(BaseResponse):
    response: "DocsGetTypesResponseModel" = Field()


class DocsGetUploadServerResponse(BaseResponse):
    response: "BaseUploadServer" = Field()


class DocsGetResponseModel(BaseModel):
    count: int = Field()
    items: list["DocsDoc"] = Field()


class DocsGetResponse(BaseResponse):
    response: "DocsGetResponseModel" = Field()


class DocsSaveResponseModel(BaseModel):
    type: "DocsDocAttachmentType | None" = Field(
        default=None,
    )
    audio_message: "MessagesAudioMessage | None" = Field(
        default=None,
    )
    doc: "DocsDoc | None" = Field(
        default=None,
    )
    graffiti: "MessagesGraffiti | None" = Field(
        default=None,
    )


class DocsSaveResponse(BaseResponse):
    response: "DocsSaveResponseModel" = Field()


class DocsSearchResponseModel(BaseModel):
    count: int = Field()
    items: list["DocsDoc"] = Field()


class DocsSearchResponse(BaseResponse):
    response: "DocsSearchResponseModel" = Field()
